kelp
----

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. image:: https://github.com/bmorris3/kelp/workflows/CI%20Tests/badge.svg
    :target: https://github.com/bmorris3/kelp/actions

.. image:: https://readthedocs.org/projects/kelp/badge/?version=latest
    :target: https://kelp.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
    
Photometric phase curves of exoplanets. `Read the docs <https://kelp.readthedocs.io/en/latest/>`_ for more info.


License
-------

This project is Copyright (c) Brett M. Morris and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause license. See the licenses folder for
more information.


Contributing
------------

We love contributions! kelp is open source,
built on open source, and we'd love to have you hang out in our community.

